@@ -4,13 +4,13 @@ from sorl.thumbnail.conf import settings
 from sorl.thumbnail.models import KVStore as KVStoreModel
 
 
-class EMPTY_VALUE(object):
+class EMPTY_VALUE:
     pass
 
 
 class KVStore(KVStoreBase):
     def __init__(self):
-        super(KVStore, self).__init__()
+        super().__init__()
 
     @property
     def cache(self):
